@@ -69,7 +69,7 @@ build_index(fz_context* ctx, fz_document* document, fz_outline* outline, girara_
 
       type                    = ZATHURA_LINK_GOTO_DEST;
       target.destination_type = ZATHURA_LINK_DESTINATION_XYZ;
-      target.page_number      = location.page;
+      target.page_number      = fz_page_number_from_location (ctx, document, location);
       target.left  = x;
       target.top   = y;
       target.zoom  = 0.0;
